Set the options of cartogramR in the correct format
cartogramR_options(
options,
method = c("gsm", "gn", "dcn", "GastnerSeguyMore", "GastnerNewman",
"DougenikChrismanNiemeyer")
)a list to be processed by cartogramR
a named list with some (or all) the following components:
maxit: (all method) the maximum number of iterations, default to 50.
maxit_internal: ("gsm" or "gn") the maximum number of internal
iterations, default to 10000.
absrel: (all method) boolean, if TRUE relative convergence
if FALSE absolute convergence (default to TRUE)
abserror: (all method) Areas on cartogram differ at most by an (absolute value of) error of abserror. That is, \(max_{polygons} |area_on_cartogram - target_area| <= abserror\) (default to 10000)
abstol: ("dcn") the absolute convergence error tolerance:
\(max_\{polygons\} |area(i) - area(i-1)|\)
default to 1000
relerror: (all method) Areas on cartogram differ at most by an (absolute value of) relative error of relerror. That is, \(max_\{polygons\} |area_on_cartogram / target_area - 1| <= relerror\) (default to 0.01)
reltol: ("dcn") the absolute convergence tolerance:
\(max_\{polygons\} abs((area(i) - area(i-1))/area(i-1)\)
default to 1e-3
L: ("gsm" or "gn") integer, gives the value of L (default
is 512), must be a power of two (for fftw)
mp: (all method) if a region contains exactly zero population, it will be replaced by mp times the smallest (strictly) positive population in any region (default to 0.2)
pf: ("gsm" or "gn") Determines space between map and boundary (default to 1.5)
sigma: ("gsm" or "gn") Width of Gaussian blur to smoothen the density (default to 5)
center: ("gsm" or "gn") either a character string
(only possible choices are "centroid"
or "point_on_surface") or a function. If the
object is a function, it will be used to
calculate the "center" of polygons; "point_on_surface"
will use the function sf::st_point_on_surface
while "centroid" (the default) will use sf::st_centroid.
verbose: (all method) integer giving the verbosity level
(default to 0, not verbose)
grid: ("gsm" or "gn") boolean, if TRUE export the final
grid from flow algorithm (default to TRUE). Setting to FALSE
check.ring.dir: (all method) boolean, if TRUE controls polygons orientation
(default to TRUE)
check.only: (all method) boolean, if TRUE control only polygons orientation
and no replacement is done (default to FALSE)
the method to be used, can be one of the following:
gsm or GastnerSeguyMore (default), gn or
GastnerNewman, dcn or DougenikChrismanNiemeyer.
Dougenik, J., Chrisman, R. & Niemeyer, D. (1985). An algorithm to construct continuous area cartograms. Professional Geographer 37: 75-81.
Gastner, M. & Newman, M. E. J. (2004). Diffusion-based method for producing density equalizing maps. Proc. Natl. Acad. Sci. USA, 101:7499-7504
Gastner, M., Seguy, V. & More, P. (2018). Fast flow-based algorithm for creating density-equalizing map projections. Proceedings of the National Academy of Sciences USA, 115:E2156-E2164
# \donttest{
data(usa)
carto1 <- cartogramR(usa, "electors64", options=list(verbose=1, L=256))
plot(carto1)
# }
Run the code above in your browser using DataLab