Learn R Programming

cartogramR (version 1.2-0)

summary.dbv.cartogramR: Summary of a dbv.cartogram object

Description

Summary of a dbv.cartogram object

Usage

# S3 method for dbv.cartogramR
summary(object, ...)

Value

a data-table which contains by region (L3)

  • the sample quantiles corresponding to the probability 0.8, 0.85, ...,1

  • the total number of vertices divided by the perimeter of the region (the sum of all polygons perimeter of the region, NbyPerim)

Arguments

object

a dbv.cartogramR object

\dots

arguments passed to or from other methods.

Examples

Run this code
  data(usa)
  dbv <- dist_between_vertices(data=usa)
  summary(dbv)

Run the code above in your browser using DataLab