Coerce a cartogramR to a sf object returning the sf object used to construct the cartogram with the cartogram as geometry and some more attributes
# S3 method for cartogramR
as.sf(x, ...)a sf object including all the data (attributes) contained in the original sf object used to construct the cartogram and
original areas of region (orig_area)
final/deformed areas of region (final_area)
target areas of region (target_area)
original centers (x_orig_centers and y_orig_centers)
final centers (x_final_centers and y_final_centers)
a cartogramR object
arguments passed to or from other methods.