Transform a sf object with several rows (polygons) by region to an sf object with one row by region and thus one multipolygon by region
as.sfmultipolygon(data, idregion, closepolygon = FALSE)a sf object with one row by region and one multipolygon by region.
a sf object
a character string which indicates the name of the
column (in data object) which contains the region
identifier.
a boolean (default to FALSE) if TRUE it
controls if polygons are closed and if not add the first
vertice at the end.