powered by
Summary of a dbv.cartogram object
# S3 method for dbv.cartogramR summary(object, ...)
a data-table which contains by region (L3)
L3
the sample quantiles corresponding to the probability 0.8, 0.85, ...,1
the total number of vertices divided by the perimeter of the region (the sum of all polygons perimeter of the region, NbyPerim)
NbyPerim
a dbv.cartogramR object
arguments passed to or from other methods.
data(usa) dbv <- dist_between_vertices(data=usa) summary(dbv)
Run the code above in your browser using DataLab